require_relative 'model/config'
require_relative 'model/localization'
require 'csv'

module Locraft
  class CSVParser
    def initialize(config)
      @config = config
    end

    def csv_rows(body)
      csv = CSV.new(body, headers: true)
      csv.to_a.map(&:to_hash)
    end

    # return localizations hash like #{ 'Lang' => [array of localizations] }
    def parse_csv(csv_body)
      rows = csv_rows(csv_body)
      localizations_hash = {}
      @config.langs.each_key do |lang|
        localizations_hash[lang] = parse_rows_for_lang(rows, lang) || []
      end
      localizations_hash
    end

    # return localizations array
    def parse_rows_for_lang(rows, lang)
      if rows.first.keys.include? lang
        rows.map { |row| Localization.load_with_csv_row(row, @config, lang) }
      else
        warn "WARNING: there is no such a language in doc file: [#{lang}]"
      end
    end
  end
end
