require_relative 'model/config'
require_relative 'csv_parser'
require_relative 'google_drive_wrapper'

module Locraft
  class Extractor
    def initialize(config_file)
      @config = Config.load_from(config_file)
    end

    def extract
      csv = GoogleDriveWrapper.new(@config).export_worksheet_csv
      csv_parser = CSVParser.new(@config)
      localizations_hash = csv_parser.parse_csv(csv)
      if localizations_hash[@config.default_lang].nil?
        warn 'extract ERROR: no localizations given'
      else
        generate_strings(localizations_hash)
      end
    end

    def generate_strings(localizations_hash)
      @config.strings_generators.each do |generator|
        generator.generate(localizations_hash)
      end
    end
  end
end
