require_relative '../model/config'
require_relative '../model/localization'
require_relative '../utils'
require_relative 'generator'
require 'fileutils'

module Locraft
  class StringsGenerator < Generator
    include FileUtils

    def valid?
      !@config.relative_strings_destination.nil?
    end

    def generate(localizations_hash)
      @config.langs.each do |lang, lang_code|
        localizations = localizations_hash[lang].select { |l| valid_localization?(l) }
        destination_dir = destination_dir_for(lang, lang_code)
        file = "#{destination_dir}/#{strings_file}"
        mkdir_p destination_dir unless Dir.exist?(destination_dir)
        File.open(file, 'w+') do |f|
          f.puts file_template % strings_file_content(localizations)
        end
        broadcast_file_generation(file)
      end
    end

    def broadcast_file_generation(f)
      puts "strings file generated: [#{f}]"
    end

    def valid_localization?(l)
      l.valid?
    end

    def file_template
      Utils.resource_file('strings_template.txt')
    end

    def destination_dir_for(_, lang_code)
      "#{@config.relative_strings_destination}/#{lang_code}.lproj"
    end

    def strings_file
      @config.strings_file
    end

    def strings_file_content(localizations)
      localizations.select(&:valid?).map { |l| strings_line_with(l) }.join("\n")
    end

    def strings_line_with(localization)
      content = ''
      content += "/* #{localization.comment} */" unless localization.comment.nil?
      content + %(\n"#{localization.key}" = "#{localization.strict_value}";\n)
    end
  end
end
