require_relative 'constants_generator'

module Locraft
  class SwiftConstantsGenerator < ConstantsGenerator
    def valid?
      !@config.relative_macro_destination.nil?
    end

    def generate(localizations_hash)
      if @config.relative_plist_destination.nil?
        warn 'Skipping objc constants generation. No destination path provided.'
        return
      end

      localizations = localizations_hash[@config.default_lang]
      destination_dir = @config.relative_macro_destination
      file_content = file_content(localizations)
      mkdir_p destination_dir unless Dir.exist?(destination_dir)
      write_file_content("#{destination_dir}/#{files_name}.swift", file_content)
      puts 'constants files was created for [swift] language'
    end

    def file_content(localizations)
      content = constants_keys_with(localizations).map { |d| const_template % d }.join("\n")
      Utils.resource_file('swift_macro_template.txt') % content
    end

    def const_template
      <<EOF
    static var %<const>s: String {
        return localized("%<key>s")
    }
EOF
    end

    def constant_from(key)
      parts = key.split(/\W/).reject(&:empty?)
      parts.map! do |p|
        p[0] = p[0].capitalize if p != parts[0]
        p
      end
      parts.join
    end
  end
end
