require_relative 'model/config'
require 'google_drive'
require 'fileutils'

module Locraft
  class GoogleDriveWrapper
    include FileUtils

    EXPORTED_CSV_FILE = 'google_doc_sheet.csv'
    SESSION_TOKEN_FILE = '.locraft_gdrive_token'

    def initialize(config)
      @config = config
    end

    def authenticate
      token_file = File.join(@config.from_folder, SESSION_TOKEN_FILE)
      @session = GoogleDrive.saved_session(token_file)
    end

    def doc_named(name)
      authenticate unless @session
      @session.spreadsheet_by_title(name)
    end

    # return worksheet
    def export_worksheet
      worksheets = doc_named(@config.gdoc_file)&.worksheets
      if worksheets.count > @config.gdoc_sheet
        worksheets[@config.gdoc_sheet]
      else
        warn 'gdrive_wrapper worksheet export error:
You have no access to google_doc or sheet number in config out of bounds!'
      end
    end

    # return exported worksheet file path
    def export_worksheet_file
      sheet = export_worksheet
      file = File.join(@config.relative_strings_destination, EXPORTED_CSV_FILE)
      File.delete(file) if File.exist?(file)
      sheet.export_as_file(file)
    end

    # return worksheet as string in csv format
    def export_worksheet_csv
      worksheet = export_worksheet
      worksheet.export_as_string
    end
  end
end
